# unitorch.models.peft

## BloomAdaLoraForClassification

::: unitorch.models.peft.BloomAdaLoraForClassification

## BloomAdaLoraForGeneration

::: unitorch.models.peft.BloomAdaLoraForGeneration

## BloomLoraForClassification

::: unitorch.models.peft.BloomLoraForClassification
    
## BloomLoraForGeneration

::: unitorch.models.peft.BloomLoraForGeneration

## LlamaAdaLoraForClassification

::: unitorch.models.peft.LlamaAdaLoraForClassification

## LlamaAdaLoraForGeneration

::: unitorch.models.peft.LlamaAdaLoraForGeneration

## LlamaLoraForClassification

::: unitorch.models.peft.LlamaLoraForClassification
    
## LlamaLoraForGeneration

::: unitorch.models.peft.LlamaLoraForGeneration
